@@ -125,7 +125,7 @@ class Adax:
 
         headers = {"Authorization": f"Bearer {self._access_token}"}
         try:
-            with async_timeout.timeout(self._timeout):
+            async with async_timeout.timeout(self._timeout):
                 if json_data:
                     response = await self.websession.post(
                         url, json=json_data, headers=headers
@@ -136,8 +136,8 @@ class Adax:
                 self._access_token = None
                 if retry > 0:
                     if response.status == 429:
-                        _LOGGER.warning("Too many requests, will retry")
-                        await asyncio.sleep(RATE_LIMIT_SECONDS * max(1, (4 - retry)))
+                        _LOGGER.warning("Too many requests")
+                        return None
                     return await self._request(url, json_data, retry=retry - 1)
                 _LOGGER.error(
                     "Error connecting to Adax, response: %s %s",
@@ -164,7 +164,7 @@ class Adax:
 async def get_adax_token(websession, account_id, password, retry=3, timeout=10):
     """Get token for Adax."""
     try:
-        with async_timeout.timeout(timeout):
+        async with async_timeout.timeout(timeout):
             response = await websession.post(
                 f"{API_URL}/auth/token",
                 headers={
